@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -76,7 +76,7 @@ bytearray::operator[] (bytearray::size_type idx) const
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief operator[]
-//! \return reference to an element of bytearray
+//! \return Reference to an element of bytearray
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 bytearray::reference
 bytearray::operator[] (bytearray::size_type idx)
@@ -89,7 +89,7 @@ bytearray::operator[] (bytearray::size_type idx)
 //! \param o another bytearray
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 bytearray&
-bytearray::operator^= (const bytearray& o)
+bytearray::operator^= (const bytearray& o) noexcept
 {
   for (size_type i = 0; i < std::min (size (), o.size ()); i++)
     {
@@ -111,15 +111,24 @@ bytearray::operator+= (const bytearray& o)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief fill array with value
+//! \brief Fill array with value
 //! \param val value to fill the array with
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
-bytearray::fill (bytearray::value_type val)
+bytearray::fill (bytearray::value_type val) noexcept
 {
   std::fill (data_.begin (), data_.end (), val);
 }
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Fill array with random bytes
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+void
+bytearray::random () noexcept
+{
+  std::generate (data_.begin (), data_.end (), std::rand);
+}
+
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief left pad bytearray
 //! \param siz new size in bytes
@@ -152,21 +161,12 @@ bytearray::rpad (size_type siz, value_type val)
     }
 }
 
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Fill array with random bytes
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-void
-bytearray::random ()
-{
-  std::generate (data_.begin (), data_.end (), std::rand);
-}
-
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief Check if all bytes are equal to value
 //! \param value Value to check
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 bool
-bytearray::all_equal (value_type value) const
+bytearray::all_equal (value_type value) const noexcept
 {
   return std::all_of (
     data_.begin(),
@@ -175,6 +175,83 @@ bytearray::all_equal (value_type value) const
   );
 }
 
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Compare bytearray slice to another bytearray
+//! \param pos Start position
+//! \param b Bytearray
+//! \return true/false
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+bool
+bytearray::compare (size_type pos, const bytearray& b) const noexcept
+{
+  return pos + b.size () <= size () && std::equal (b.begin (), b.end (), begin () + pos);
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Check if bytearray starts with another bytearray
+//! \param b Bytearray
+//! \return true/false
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+bool
+bytearray::startswith (const bytearray& b) const noexcept
+{
+  return compare (0, b);
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Check if bytearray ends with another bytearray
+//! \param b Bytearray
+//! \return true/false
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+bool
+bytearray::endswith (const bytearray& b) const noexcept
+{
+  return compare (size () - b.size (), b);
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Search for sequence inside bytearray
+//! \param b Sequence data
+//! \return Sequence position or <i>notfound</i> if not found
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+bytearray::pos_type
+bytearray::find (const bytearray& b) const noexcept
+{
+  if (b.size () > size ())
+    return notfound;
+
+  const auto siz = size () - b.size ();
+
+  for (size_type i = 0;i <= siz;i++)
+    {
+      if (std::equal (b.begin (), b.end (), data_.begin () + i))
+        return i;
+    }
+
+  return notfound;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief Search for sequence inside bytearray, starting from the end
+//! \param b Sequence data
+//! \return Sequence position or <i>notfound</i> if not found
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+bytearray::pos_type
+bytearray::rfind (const bytearray& b) const noexcept
+{
+  if (b.size () > size ())
+    return notfound;
+
+  const auto siz = size () - b.size ();
+
+  for (pos_type i = siz;i >= 0;i--)
+    {
+      if (std::equal (b.begin (), b.end (), data_.begin () + i))
+        return i;
+    }
+
+  return notfound;
+}
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief create a new bytearray from a subset of bytearray
 //! \param start start position
@@ -270,7 +347,7 @@ bytearray::dump () const
 
   for (std::uint64_t i = 0; i < data_.size (); i += 16)
     {
-      dump += mobius::string::to_hex (i, 4);
+      dump += mobius::string::to_hex (i, 8);
       dump += " ";
 
       for (int j = 0; j < 16; j++)
