@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -16,20 +16,19 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 import pymobius.operating_system
-import pymobius.vfs
 import pymobius.registry.installed_programs
-from pymobius.registry import *
 import pymobius.p2p
 import pymobius.p2p.account
 import pymobius.p2p.application
 import pymobius.p2p.search
 import pymobius.p2p.remote_file
 import pymobius.registry
-import decoder_torrenth_dat
-import decoder_tempdl_phash_dat
-import pymobius.p2p.ares.profile
 import mobius
 import binascii
+from . import decoder_torrenth_dat
+from . import decoder_tempdl_phash_dat
+from . import profile
+from pymobius.registry import *
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # References:
@@ -98,7 +97,7 @@ def iter_ares_folders (item):
         folder = user_profile.get_entry_by_path ('%localappdata%/Ares')
         if folder:
           yield user_profile, folder
-      except Exception, e:
+      except Exception as e:
         mobius.core.logf ('WRN p2p.ares: ' + str (e))
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -111,9 +110,9 @@ def retrieve (model):
   try:
     ant = Ant (model)
     ant.run ()
-  except Exception, e:
-    mobius.core.logf ('WRN p2p.ares: ' + str (e) + ' ' + traceback.format_exc ())
-  
+  except Exception as e:
+    mobius.core.logf ('WRN %s %s' % (str (e), traceback.format_exc ()))
+
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # @brief forensics: P2P Ares
 # @author Eduardo Aguiar
@@ -182,12 +181,13 @@ class Ant (object):
     for username, user_key in pymobius.registry.iter_hkey_users (registry):
       for subkey in user_key.get_key_by_mask ('Software\\Ares\\Search.History\\*'):
         for value in subkey.values:
-          keyword = binascii.unhexlify (value.name)
+          keyword = binascii.unhexlify (value.name).decode ('utf-8')
           search = pymobius.p2p.search.search ()
           search.app_id = 'ares'
           search.app = 'Ares Galaxy'
           search.text = keyword
           search.username = username
+          search.count = -1
           search.add_metadata ('Application', 'Ares Galaxy')
           search.add_metadata ('Search Term', search.text)
           search.add_metadata ('Category', subkey.name)
@@ -281,7 +281,7 @@ class Ant (object):
       lf.add_metadata ('URL', entry.url)
       lf.add_metadata ('Comment', entry.comment)
       lf.add_metadata ('Filetype', entry.filetype)
-      
+
       add_metadata (lf, 'Download start time', metadata.get ('download_start_time'))
       add_metadata (lf, 'Download completed time', entry.download_completed_time)
       add_metadata (lf, 'Bytes downloaded', metadata.get ('bytes_downloaded'))
@@ -340,7 +340,7 @@ class Ant (object):
   # @brief Add data from profile.get_remote_files
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   def __add_remote_files (self, item, model, profile):
-    
+
     # add remote files
     for entry in profile.get_remote_files ():
       lf = pymobius.p2p.remote_file.remote_file ()
@@ -355,7 +355,7 @@ class Ant (object):
       lf.set_hash ('sha1', entry.hash_sha1)
 
       # metadata
-      if 'local_timestamp' in entry.metadata: 
+      if 'local_timestamp' in entry.metadata:
         lf.add_metadata ('Local timestamp', entry.metadata.get ('local_timestamp'))
 
       lf.add_metadata ('Title', entry.title)
@@ -367,11 +367,11 @@ class Ant (object):
       lf.add_metadata ('URL', entry.url)
       lf.add_metadata ('Comment', entry.comment)
       lf.add_metadata ('Filetype', entry.filetype)
-      
+
       # peer data
       lf.peer.ip = entry.peer_ip
       lf.peer.port = entry.peer_port
-      
+
       # add to model
       model.remote_files.append (lf)
 
@@ -381,7 +381,7 @@ class Ant (object):
   def __add_torrenth_dat (self, item, model, profile):
 
     # add local files
-    for entry in profile.torrenth.itervalues ():
+    for entry in profile.torrenth.values ():
       lf = local_file ()
       lf.app_id = 'ares'
       lf.app = 'Ares Galaxy'
@@ -431,7 +431,7 @@ class Ant (object):
   # @brief Add data from My Shared Folder/___ARESTRA___ files to model
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   def __add_arestra (self, item, model, profile):
-    for entry in profile.arestra.itervalues ():
+    for entry in profile.arestra.values ():
 
       #-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
       # create local file
@@ -443,9 +443,9 @@ class Ant (object):
       lf.size = entry.size
       lf.name = entry.name
       lf.username = profile.username
-    
+
       if entry.size > 0:
-        pct_progress = float (entry.progress) * 100.0 / float (entry.size) 
+        pct_progress = float (entry.progress) * 100.0 / float (entry.size)
       else:
         pct_progress = 0.0
 
@@ -490,7 +490,7 @@ class Ant (object):
         lf.name = entry.name
         lf.username = profile.username
         lf.timestamp = entry.creation_time
-      
+
         # hash
         lf.set_hash ('sha1', entry.hash_sha1)
 
@@ -506,11 +506,11 @@ class Ant (object):
         lf.add_metadata ('URL', entry.url)
         lf.add_metadata ('Comments', entry.comment)
         lf.add_metadata ('Filetype', entry.filetype)
-      
+
         # peer data
         lf.peer.ip = source.ip
         lf.peer.port = source.port
-      
+
         # add to model
         model.remote_files.append (lf)
 
