@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -15,16 +15,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-import pymobius.vfs
+import traceback
+import mobius
 import pymobius.registry.installed_programs
 from pymobius.registry import *
 import pymobius.p2p.application
-import decoder_sd
-import decoder_library_dat
-import decoder_profile_xml
-import decoder_searches_dat
-import mobius
-import traceback
+from . import decoder_sd
+from . import decoder_library_dat
+from . import decoder_profile_xml
+from . import decoder_searches_dat
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # All Date/Times are stored in Coordinated Universal Time (UTC).
@@ -55,8 +54,8 @@ def iter_shareaza_folders (item):
         folder = user_profile.get_entry_by_path ('%appdata%/Shareaza')
         if folder:
           yield user_profile, folder
-      except Exception, e:
-        mobius.core.logf ('WRN p2p.shareaza: ' + str (e))
+      except Exception as e:
+        mobius.core.logf ('WRN %s %s' % (str (e), traceback.format_exc ()))
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # @brief Retrieves Shareaza P2P activity data
@@ -68,8 +67,8 @@ def retrieve (model):
   try:
     ant = Ant (model)
     ant.run ()
-  except Exception, e:
-    mobius.core.logf ('WRN p2p.shareaza: ' + str (e) + ' ' + traceback.format_exc ())
+  except Exception as e:
+    mobius.core.logf ('WRN %s %s' % (str (e), traceback.format_exc ()))
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # @brief forensics: P2P Shareaza
@@ -123,7 +122,7 @@ class Ant (object):
       for program in pymobius.registry.installed_programs.get (registry):
         if program.display_name.startswith ('Shareaza '):
           self.__data.application.versions.add (program.version)
-    
+
     # Shareaza folders
     #for username, key in pymobius.registry.iter_hkey_users (registry):
     #  shareaza_key = key.get_key_by_path ('Software\\Shareaza\\Shareaza')
@@ -149,8 +148,8 @@ class Ant (object):
         incomplete_folder = user_profile.get_entry_by_path ('%localappdata%/Shareaza/Incomplete')
 
         self.__retrieve_incomplete_folder (incomplete_folder, user_profile.username)
-      except Exception, e:
-        mobius.core.logf ('WRN p2p.shareaza: ' + str (e))
+      except Exception as e:
+        mobius.core.logf ('WRN %s %s' % (str (e), traceback.format_exc ()))
 
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   # @brief Retrieve Data folder evidence files
@@ -161,7 +160,7 @@ class Ant (object):
 
     f = folder.get_child_by_name ('Searches.dat', False)
     decoder_searches_dat.retrieve (self.__item, self.__data, f, username)
-  
+
     f = folder.get_child_by_name ('Library1.dat', False)
     if not f:
       f = folder.get_child_by_name ('Library2.dat', False)
@@ -174,7 +173,7 @@ class Ant (object):
   # @brief retrieve incomplete control files
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   def __retrieve_incomplete_folder (self, folder, username):
-  
+
     if not folder or not folder.is_folder ():
       return
 
@@ -192,7 +191,7 @@ class Ant (object):
     timestamp, peer_ip, size, name = None, None, None, None
     self.__data.remote_files = []
 
-    for (timestamp, f) in sorted (remote_files):
+    for (timestamp, f) in sorted (remote_files, key=lambda x: x[0]):
       if (timestamp, peer_ip, size, name) != (f.timestamp, f.peer.ip, f.size, f.name):
         self.__data.remote_files.append (f)
         timestamp, peer_ip, size, name = f.timestamp, f.peer.ip, f.size, f.name
