@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -564,9 +564,12 @@ testcase_uri ()
   test.ASSERT_EQUAL (uri6.get_path (), "+1-816-555-1212");
   test.ASSERT_EQUAL (uri7.get_path (), "/");
   test.ASSERT_EQUAL (uri8.get_path (), "oasis:names:specification:docbook:dtd:xml:4.1.2");
-  test.ASSERT_EQUAL (uri9.get_path (), "/test/subdir 1");
-  test.ASSERT_EQUAL (uri10.get_path (), "/test/subdir 1");
-  test.ASSERT_EQUAL (uri12.get_path (), "/test with space%/a%b");
+  test.ASSERT_EQUAL (uri9.get_path (), "/test/subdir%201");
+  test.ASSERT_EQUAL (uri9.get_path ("utf-8"), "/test/subdir 1");
+  test.ASSERT_EQUAL (uri10.get_path (), "/test/subdir%201");
+  test.ASSERT_EQUAL (uri10.get_path ("utf-8"), "/test/subdir 1");
+  test.ASSERT_EQUAL (uri12.get_path (), "/test%20with%20space%25/a%25b");
+  test.ASSERT_EQUAL (uri12.get_path ("utf-8"), "/test with space%/a%b");
 
   // query
   test.ASSERT_EQUAL (uri1.get_query (), "");
@@ -669,9 +672,12 @@ testcase_uri ()
   test.ASSERT_EQUAL (uri6.get_filename (), "");
   test.ASSERT_EQUAL (uri7.get_filename (), "");
   test.ASSERT_EQUAL (uri8.get_filename (), "");
-  test.ASSERT_EQUAL (uri9.get_filename (), "subdir 1");
-  test.ASSERT_EQUAL (uri10.get_filename (), "subdir 1");
-  test.ASSERT_EQUAL (uri12.get_filename (), "a%b");
+  test.ASSERT_EQUAL (uri9.get_filename (), "subdir%201");
+  test.ASSERT_EQUAL (uri9.get_filename ("utf8"), "subdir 1");
+  test.ASSERT_EQUAL (uri10.get_filename (), "subdir%201");
+  test.ASSERT_EQUAL (uri10.get_filename ("utf8"), "subdir 1");
+  test.ASSERT_EQUAL (uri12.get_filename (), "a%25b");
+  test.ASSERT_EQUAL (uri12.get_filename ("utf8"), "a%b");
 
   // extension
   test.ASSERT_EQUAL (uri1.get_extension (), "txt");
